@@ -21,7 +21,7 @@ class ModelApp:
     def __init__(self, app):
         self.app = app
 
-    def create_model(self, name, type, dataset=None):
+    def create_model(self, name, type, dataset=None, dependencies=None):
         """
         Create and return a new model .
 
@@ -29,14 +29,15 @@ class ModelApp:
             name (str): The name of the model.
             type (ModelType): The type of Model, see the ModelType class.
             dataset (DataSet): An optional DataSet for training or testing the model.
-
+            dependencies (list): A list of modules this model depends on.
         Returns:
             Model: The new model.
         """
         body = {
             "name": name,
             "type": getattr(type, 'name', str(type)),
-            "datasetId": as_id(dataset)
+            "datasetId": as_id(dataset),
+            "dependencies": dependencies
         }
         return Model(self.app.client.post("/api/v3/models", body))
 
@@ -193,6 +194,28 @@ class ModelApp:
 
         return self.app.client.post(f'/api/v3/models/{mid}/_deploy')
 
+    def update_model(self, model, **kwargs):
+        """
+        Update various model properties.
+
+        Args:
+            model (Model): A model object or unique Model Id.
+
+        Keyword Args:
+            name (str): A new name for the model. Changing the model
+                name will change where the results are stored in the Asset's analysis metadata.
+            dataset (Dataset): A dataset or unique Dataset Id.
+            dependencies (list): A list of modules that should run before this model.
+        Returns:
+            Model: The updated model.
+        """
+        mid = as_id(model)
+        if 'dataset' in kwargs:
+            kwargs['datasetId'] = as_id(kwargs.get('dataset'))
+            del kwargs['dataset']
+        self.app.client.patch(f'/api/v3/models/{mid}', kwargs)
+        return self.get_model(mid)
+
     def export_trained_model(self, model, dst_file, tag='latest'):
         """
         Download a zip file containing the model.
