@@ -122,6 +122,11 @@ class Model(BaseEntity):
         """The type of model"""
         return ModelState[self._data['state']]
 
+    @property
+    def dependencies(self):
+        """Modules that must run before this model"""
+        return self._data.get('dependencies', list())
+
     @property
     def uploadable(self):
         """True of the model should be uploaded"""
