@@ -4,6 +4,18 @@ import uuid
 import decimal
 import zipfile
 import os
+import json
+import datetime
+from enum import Enum
+
+
+def enum_name(en, value, caps=False):
+    if isinstance(value, Enum):
+        return value.name
+    else:
+        if caps:
+            value = value.upper()
+        return en[value].name
 
 
 def is_valid_uuid(val):
@@ -84,8 +96,39 @@ def as_id_collection(value):
     if value is None:
         return None
     if isinstance(value, (set, list, tuple, dict)):
-        return [getattr(it, "id", it) for it in value]
-    return [getattr(value, "id", value)]
+        return [getattr(it, 'id', it) for it in value]
+    return [getattr(value, 'id', value)]
+
+
+def as_name(value):
+    """
+    Return the name of an Entity or the string value of the object.
+
+    Args:
+        value (Entity): The BoonAI entity.
+
+    Returns:
+        str: The name of the eneity.
+    """
+    return getattr(value, 'name', str(value))
+
+
+def as_name_collection(value):
+    """
+    Iterate values and convert to a list of names using the 'name' property.  Single
+    object saree automatically wrapped in a list.
+
+    Args:
+        value (list):  A list or scalar object.
+
+    Returns:
+        list: A list of strings.
+    """
+    if value is None:
+        return None
+    if isinstance(value, (set, list, tuple)):
+        return [getattr(it, 'name', it) for it in value]
+    return [getattr(value, 'name', value)]
 
 
 def memoize(func):
@@ -192,3 +235,61 @@ def denormalize_bbox(img_width, img_height, poly):
         else:
             result.append(int(poly[idx] * img_height))
     return result
+
+
+def to_json(obj, indent=None):
+    """
+    Convert the given object to a JSON string using
+    the BoonSdkJsonEncoder.
+
+    Args:
+        obj (mixed): any json serializable python object.
+        indent (int): The indentation level for the json, or None for compact.
+    Returns:
+        str: The serialized object
+
+    """
+    return json.dumps(obj, cls=BoonSdkJsonEncoder, indent=indent)
+
+
+def print_json(obj, indent=2):
+    """
+    Convert the given object to a JSON string and print to stdout.
+
+    Args:
+        obj (mixed): any json serializable python object.
+        indent (int): The indentation level for the json, or None for compact.
+    Returns:
+        str: The serialized object
+
+    """
+    print(json.dumps(obj, cls=BoonSdkJsonEncoder, indent=indent))
+
+
+def chunked(lst, n):
+    """Yield successive n-sized chunks from lst."""
+    for i in range(0, len(lst), n):
+        yield lst[i:i + n]
+
+
+class BoonSdkJsonEncoder(json.JSONEncoder):
+    """
+    JSON encoder for with Boon AI specific serialization defaults.
+    """
+
+    def default(self, obj):
+        if hasattr(obj, 'for_json'):
+            return obj.for_json()
+        elif isinstance(obj, (set, frozenset)):
+            return list(obj)
+        elif isinstance(obj, datetime.datetime):
+            return obj.isoformat()
+        elif isinstance(obj, datetime.date):
+            return obj.isoformat()
+        elif isinstance(obj, datetime.time):
+            return obj.isoformat()
+        elif isinstance(obj, decimal.Decimal):
+            return float(obj)
+
+        # Let the base class default method raise the TypeError
+        return json.JSONEncoder.default(self, obj)
